package dev.fitko.fitconnect.integrationtests.condition;

import dev.fitko.fitconnect.core.util.Strings;
import org.junit.jupiter.api.extension.ConditionEvaluationResult;
import org.junit.jupiter.api.extension.ExecutionCondition;
import org.junit.jupiter.api.extension.ExtensionContext;

import java.util.stream.Stream;

import static org.junit.jupiter.api.extension.ConditionEvaluationResult.*;

public class EnableIfEnvironmentVariablesAreSetCondition implements ExecutionCondition {

    @Override
    public ConditionEvaluationResult evaluateExecutionCondition(final ExtensionContext extensionContext) {
        return allVariablesSet() ? enabled("") : disabled("environment variables are not set");
    }

    private boolean allVariablesSet() {
        final String destinationIdJsonData = System.getenv("TEST_DESTINATION_ID_JSON_DATA");
        final String destinationIdXmlData = System.getenv("TEST_DESTINATION_ID_XML_DATA");
        final String senderClientId = System.getenv("SENDER_CLIENT_ID");
        final String senderClientSecret = System.getenv("SENDER_CLIENT_SECRET");
        final String subscriberClientId = System.getenv("SUBSCRIBER_CLIENT_ID");
        final String subscriberClientSecret = System.getenv("SUBSCRIBER_CLIENT_SECRET");
        return Stream.of(destinationIdJsonData, destinationIdXmlData, senderClientId, senderClientSecret, subscriberClientId, subscriberClientSecret).allMatch(Strings::isNotNullOrEmpty);
    }
}
